@@ -61,17 +61,16 @@ class PullResult(list):
         nextBeginOffset:Optional[int] = None,
         minOffset:Optional[int] = None, 
         maxOffset:Optional[int] = None,
-        msgFoundList:Union[ArrayList, List[MessageExt], None] = None,
+        msgFoundList:Optional[List[MessageExt]] = None,
     ):
         if pull_result is None == (pullStatus is None or nextBeginOffset is None or minOffset is None or maxOffset is None or msgFoundList is None):
             raise Exception('Exactly one of pull_result and nextBeginOffset+minOffset+maxOffset+msgFoundList must be specified')
         elif pull_result is not None:
             self.this = pull_result
+            list.__init__(self, self.msgFoundList)
         else:
-            self.this = JPullResult(pullStatus.value, nextBeginOffset, minOffset, maxOffset,
-                msgFoundList if isinstance(msgFoundList,ArrayList) else ArrayList([m.this for m in msgFoundList])
-            )
-        list.__init__(self, [MessageExt(msg) for msg in self.this.getMsgFoundList()])
+            self.this = JPullResult(pullStatus.value, nextBeginOffset, minOffset, maxOffset, ArrayList([m.this for m in msgFoundList]))
+            list.__init__(self, msgFoundList)
 
     @property
     def pullStatus(self) -> PullStatus:
@@ -88,6 +87,10 @@ class PullResult(list):
     @property
     def maxOffset(self) -> int:
         return int(self.this.getMaxOffset())
+    
+    @property
+    def msgFoundList(self) -> List[MessageExt]:
+        return [MessageExt(msg) for msg in self.this.getMsgFoundList() or []]
 
 @JImplements(JPullCallback)
 class PullCallback:
@@ -156,7 +159,7 @@ class BaseConsumer(BaseClient):
         self.this.sendMessageBack(msg.this, delayLevel, brokerName)
 
     def fetchSubscribeMessageQueues(self, topic:str) -> List[MessageQueue]:
-        return [MessageQueue(mq) for mq in self.this.fetchSubscribeMessageQueues(topic)]
+        return [MessageQueue(mq) for mq in self.this.fetchSubscribeMessageQueues(topic) or []]
 
     @property
     def offsetStore(self) -> OffsetStore:
@@ -212,7 +215,7 @@ class PullConsumer(BaseConsumer):
     
     @property
     def registerTopics(self) -> List[str]:
-        return [str(t) for t in self.this.getRegisterTopics()]
+        return [str(t) for t in self.this.getRegisterTopics() or []]
 
     def setRegisterTopics(self, registerTopics:Union[HashSet,List[str]]):
         rt = registerTopics if isinstance(registerTopics,HashSet) else HashSet(registerTopics)
@@ -247,7 +250,7 @@ class PullConsumer(BaseConsumer):
         return int(self.this.fetchConsumeOffset(mq.this, fromStore))
     
     def fetchMessageQueuesInBalance(self, topic:str) -> List[MessageQueue]:
-        return [MessageQueue(mq) for mq in self.this.fetchMessageQueuesInBalance(topic)]
+        return [MessageQueue(mq) for mq in self.this.fetchMessageQueuesInBalance(topic) or []]
 
 class PushConsumer(BaseConsumer):
     def __init__(self, consumerGroup:Optional[str]=None):
@@ -332,7 +335,7 @@ class PushConsumer(BaseConsumer):
 
     @property
     def subscription(self) -> Dict[str,str]:
-        return {str(k):str(v) for k,v in self.this.getSubscription().items()}
+        return {str(k):str(v) for k,v in (self.this.getSubscription() or {}).items()}
 
     def setSubscription(self, subscription:Dict[dict,dict]):
         self.this.setSubscription(subscription)
